@@ -125,7 +125,7 @@ class pushover:
             dbTable=self.dbTable
         )
         self.db.execute(sql)
-        self.colNames = [n[0] for n in db.fetchall()]
+        self.colNames = [n[0] for n in self.db.fetchall()]
         self.db.close()
 
     def addUser(self, user_tkn, device=None):
